Unix Technical Forum

SVN Commit by dpage: r4133 - trunk/www/pgadmin3/cnt

This is a discussion on SVN Commit by dpage: r4133 - trunk/www/pgadmin3/cnt within the pgsql Interfaces Pgadmin Hackers forums, part of the PostgreSQL category; --> Author: dpage Date: 2005-05-04 16:50:30 +0100 (Wed, 04 May 2005) New Revision: 4133 Modified: trunk/www/pgadmin3/cnt/cnt_download.php trunk/www/pgadmin3/cnt/cnt_support.php trunk/www/pgadmin3/cnt/cnt_translation.php Log: Further ...


Go Back   Unix Technical Forum > Database Server Software > PostgreSQL > pgsql Interfaces Pgadmin Hackers

Register FAQ Members List Calendar Search Today's Posts Mark Forums Read
  #1 (permalink)  
Old 04-17-2008, 04:40 PM
svn@pgadmin.org
 
Posts: n/a
Default SVN Commit by dpage: r4133 - trunk/www/pgadmin3/cnt

Author: dpage
Date: 2005-05-04 16:50:30 +0100 (Wed, 04 May 2005)
New Revision: 4133

Modified:
trunk/www/pgadmin3/cnt/cnt_download.php
trunk/www/pgadmin3/cnt/cnt_support.php
trunk/www/pgadmin3/cnt/cnt_translation.php
Log:
Further CVS->SVN changes

Modified: trunk/www/pgadmin3/cnt/cnt_download.php
================================================== =================
--- trunk/www/pgadmin3/cnt/cnt_support.php 2005-05-04 15:45:02 UTC (rev 4132)
+++ trunk/www/pgadmin3/cnt/cnt_support.php 2005-05-04 15:50:30 UTC (rev 4133)
@@ -33,9 +33,9 @@
<table width="100%" border="0" cellspacing="1" cellpadding="8" bgcolor="#efefef" dir='ltr'>
<tr><td>
<?php echo _("This section is available in English only.");?><br><br>
- <?php echo _("The information displayed is extracted automatically from pgAdmin CVS.");?>
+ <?php echo _("The information displayed is extracted automatically from the pgAdmin SVN.");?>
<?php
- $_file=$_SERVER["DOCUMENT_ROOT"]."/cvsroot/pgadmin3/BUGS.txt";
+ $_file=$_SERVER["DOCUMENT_ROOT"]."/svnrepo/BUGS.txt";
if (file_exists($_file)) {
echo ("<br><br>");
include_once ($_file);

Modified: trunk/www/pgadmin3/cnt/cnt_translation.php
================================================== =================
--- trunk/www/pgadmin3/cnt/cnt_translation.php 2005-05-04 15:45:02 UTC (rev 4132)
+++ trunk/www/pgadmin3/cnt/cnt_translation.php 2005-05-04 15:50:30 UTC (rev 4133)
@@ -106,29 +106,7 @@

<li>
Download <a href="http://poedit.sourceforge.net">poEdit</a> and install it under MS Windows or GNU/Linux. <br><br>
- <a href="http://poedit.sourceforge.net">poEdit</a> is our recommended choice, as it makes it really easy to maintain your translation. An MS Windows installer is available on <a href="http://poedit.sourceforge.net">poEdit</a> web site. For GNU/Linux and FreeBSD users, we provide packages built against GTK2 with Unicode support. At the moment, only our packages support Unicode and enable the translation of Right-To-Left (RTL) languages like Arabic or Persian. We are in the process of submitting the packages back to poEdit team. Download precompiled poEdit binaries for:<br>
- <ul>
- <li><a href="http://snake.pgadmin.org/snapshots/freeBSD/5.1/poEdit/">FreeBSD 5.1</a>
- <li>GNU/Linux
- <a href="http://www.pgadmin.org/snapshots/linux/mandrake91/poEdit">Mandrake 9.1</a>
- - <a href="http://www.pgadmin.org/snapshots/linux/redhat9/poEdit">RedHat 9</a>
- - <a href="http://www.pgadmin.org/snapshots/linux/suse82/poEdit">Suse 8.2</a>
- <li>Debian users can install poEdit from this repository:
- <br>
- <table width="100%" border="0" cellspacing="1" cellpadding="8" bgcolor="#efefef">
- <tr><td>
- deb http://www.pgadmin.org/snapshots/linux/debian unstable pgadmin
- </td></tr>
- </table>
- <br>
- entering the following command:
- <br>
- <table width="100%" border="0" cellspacing="1" cellpadding="8" bgcolor="#efefef">
- <tr><td>
- apt-get update; apt-get install pgadmin3-poedit
- </td></tr>
- </table>
- </ul>
+ <a href="http://poedit.sourceforge.net">poEdit</a> is our recommended choice, as it makes it really easy to maintain your translation. An MS Windows installer is available on the <a href="http://poedit.sourceforge.net">poEdit</a> web site.
Alternatively, you may also run <a href="http://i18n.kde.org/tools/kbabel/">Kbabel</a> which can be found in recent GNU/Linux distributions.
<br><br>

@@ -195,7 +173,7 @@
<dd>
<ol>
<li>
- <a href='../../cvsroot/pgadmin3/pgadmin3.pot'>pgadmin3.pot</a> template file contains many SQL keywords (like 'ACL', 'AFTER', 'ANALYSE', etc...) which should not be translated. Some translators pointed out this issue, which cannot be fixed at present. Here is a short explaination: <a href='../../cvsroot/pgadmin3/pgadmin3.pot'>pgadmin3.pot</a> template file is generated by the <a href='../../cvsroot/pgadmin3/stringextract'>stringextract</a> script, which extracts text from XRC dialogs using a wxWindows utility called 'wxrc'. The problem stems from wxrc, which extracts all text entries in dialogs, even SQL entries which should not be translated.<br><br>
+ <a href='/svnrepo/pgadmin3.pot'>pgadmin3.pot</a> template file contains many SQL keywords (like 'ACL', 'AFTER', 'ANALYSE', etc...) which should not be translated. Some translators pointed out this issue, which cannot be fixed at present. Here is a short explaination: <a href='/svnrepo/pgadmin3.pot'>pgadmin3.pot</a> template file is generated by the <a href='/svnrepo/stringextract'>stringextract</a> script, which extracts text from XRC dialogs using a wxWindows utility called 'wxrc'. The problem stems from wxrc, which extracts all text entries in dialogs, even SQL entries which should not be translated.<br><br>

To make it easier, all SQL keywords are written in capital letters. Conversely, all capital letters entries are SQL keywords.<br><br>



---------------------------(end of broadcast)---------------------------
TIP 9: the planner will ignore your desire to choose an index scan if your
joining column's datatypes do not match

Digg this Post!Add Post to del.icio.usBookmark Post in TechnoratiFurl this Post!
Reply With Quote
Reply


Thread Tools
Display Modes

Posting Rules
You may not post new threads
You may not post replies
You may not post attachments
You may not edit your posts

vB code is On
Smilies are On
[IMG] code is On
HTML code is Off
Trackbacks are On
Pingbacks are On
Refbacks are On
Forum Jump


All times are GMT. The time now is 08:48 AM.


Powered by vBulletin® Version 3.6.5
Copyright ©2000 - 2008, Jelsoft Enterprises Ltd.
SEO by vBSEO 3.2.0
www.UnixAdminTalk.com
--- trunk/www/pgadmin3/cnt/cnt_download.php 2005-05-04 15:45:02 UTC (rev 4132)
+++ trunk/www/pgadmin3/cnt/cnt_download.php 2005-05-04 15:50:30 UTC (rev 4133)
@@ -407,7 +407,7 @@
<tr><td>
# Warning: MacOsX port is completely experimental.<br/>
# This information is intended for pgAdmin team only.<br/>
# Please checkout wxWindows and pgAdmin from CVS only.<br/>
# To coordinate efforts, please contact us on the mailing list<br/>
<br/>
# <?php echo _("Note - release builds should be configured without the --enable-debug option.");?><br/><br/>
@@ -462,7 +462,7 @@

<h1 id="snapshots"><?php echo _("Installing pgAdmin III from binary snapshots");?></h1>
<dd>
- <?php echo sprintf(_("Binary snapshots are packages compiled from <a href='%s'>CVS</a> nearly everyday."), "development.php#cvs");?>
+ <?php echo sprintf(_("Binary snapshots are packages compiled from <a href='%s'>SVN</a> nearly everyday."), "development.php#svn");?>
<?php echo _("There is no guarantee that these packages work in any way: it is alpha developer software intended for testing and development.");?>
<?php echo _("Because compiling from source requires technical knowledge, we recommand using binary packages.")?>
<?php echo _("Download pgAdmin III snapshots here:");?>
@@ -407,7 +407,7 @@
# Warning: MacOsX port is completely experimental.<br/>
# This information is intended for pgAdmin team only.<br/>
- # Please checkout wxWindows and pgAdmin from CVS only.<br/>
+ # Please checkout wxWindows and pgAdmin from CVS/SVN only.<br/>
# To coordinate efforts, please contact us on the mailing list<br/>
<br/>

Modified: trunk/www/pgadmin3/cnt/cnt_support.php
================================================== =================